==> aliyun-python-sdk-saf-2.0.2.tar.gz: aliyun-python-sdk-saf-2.0.2/aliyunsdksaf/request/v20190521/ExecuteExtendServiceRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdksaf.endpoint import endpoint_data

class ExecuteExtendServiceRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'saf', '2019-05-21', 'ExecuteExtendService','SAF')
		self.set_method('POST')
		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())


	def get_ServiceParameters(self):
		return self.get_query_params().get('ServiceParameters')

	def set_ServiceParameters(self,ServiceParameters):
		self.add_query_param('ServiceParameters',ServiceParameters)

	def get_Service(self):
		return self.get_query_params().get('Service')

	def set_Service(self,Service):
		self.add_query_param('Service',Service)

	def get_Region(self):
		return self.get_query_params().get('Region')

	def set_Region(self,Region):
		self.add_query_param('Region',Region)

==> aliyun-python-sdk-saf-2.0.6.tar.gz: aliyun-python-sdk-saf-2.0.6/aliyunsdksaf/request/v20190521/ExecuteExtendServiceRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdksaf.endpoint import endpoint_data

class ExecuteExtendServiceRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'saf', '2019-05-21', 'ExecuteExtendService','saf')
		self.set_method('POST')
		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())


	def get_ServiceParameters(self):
		return self.get_query_params().get('ServiceParameters')

	def set_ServiceParameters(self,ServiceParameters):
		self.add_query_param('ServiceParameters',ServiceParameters)

	def get_Service(self):
		return self.get_query_params().get('Service')

	def set_Service(self,Service):
		self.add_query_param('Service',Service)

	def get_Region(self):
		return self.get_query_params().get('Region')

	def set_Region(self,Region):
		self.add_query_param('Region',Region)
